@@ -5,8 +5,7 @@
 #include "simdjson/lasx/base.h"
 #endif // SIMDJSON_CONDITIONAL_INCLUDE
 
-// This should be the correct header whether
-// you use visual studio or other compilers.
+#include <lsxintrin.h>
 #include <lasxintrin.h>
 
 static_assert(sizeof(__m256i) <= simdjson::SIMDJSON_PADDING, "insufficient padding for LoongArch ASX");
